import asyncio
from typing import Annotated
from fastapi import (
    APIRouter,
    BackgroundTasks,
    Depends,
)
from .histories.views import (
    router as histories_router,
)
from .schemas import ExportRequest, Wallet
from .use_cases import GetWallet
from app.dependencies import APIKey
from app.exceptions import NotFound

router = APIRouter(prefix="/wallets")

@router.get("")
async def list_wallets() -> list[Wallet]:
    return [
        Wallet(wallet_id=1),
        Wallet(wallet_id=2),
    ]

@router.get("/{wallet_id}")
async def get_wallet(
    wallet_id: int,
    use_case: Annotated[GetWallet, Depends(GetWallet)],
) -> Wallet:
    return await use_case.execute(wallet_id)

async def export_wallets(dest: str) -> None:
    print(f"Exporting...")
    # 長時間処理のモック
    await asyncio.sleep(5)
    print(f"Completed: {dest}")

@router.post("/export", status_code=202)
async def export(
    data: ExportRequest,
    background_tasks: BackgroundTasks,
) -> None:
    background_tasks.add_task(
        export_wallets, data.dest
    )

router.include_router(
    histories_router, prefix="/{wallet_id}"
)
