import logging
from typing import Annotated, AsyncIterator
from fastapi import Depends
from sqlalchemy.exc import SQLAlchemyError
from sqlalchemy.ext.asyncio import (
    async_sessionmaker,
    create_async_engine,
)
from app.exceptions import AppException

logger = logging.getLogger(__name__)
async_engine = create_async_engine(
    "sqlite+aiosqlite:///database.db",
)
AsyncSessionLocal = async_sessionmaker(
    bind=async_engine,
    autoflush=False,
)

async def get_session() -> AsyncIterator[
    async_sessionmaker
]:
    try:
        yield AsyncSessionLocal
    except SQLAlchemyError as e:
        logger.exception(e)
        raise AppException() from e

AsyncSession = Annotated[
    async_sessionmaker, Depends(get_session)
]
