from contextlib import asynccontextmanager
from fastapi import Depends, FastAPI
from .api import router as api_router
from .dependencies import get_api_key
from .exceptions import init_exception_handler
from .middlewares import init_middlewares

@asynccontextmanager
async def lifespan(app: FastAPI):
    # 最初のリクエストの処理前に行われる前処理を記述
    print("startup!!!")
    yield
    # 最後のリクエストの処理後に行われる後処理を記述
    print("shutdown!!!")

app = FastAPI(lifespan=lifespan)
init_exception_handler(app)
init_middlewares(app)
app.include_router(
    api_router,
    prefix="/api",
    dependencies=[Depends(get_api_key)])
